#!/usr/bin/perl
# $Id: modify.pl,v 1.7 2001/10/24 18:12:57 will Exp $
#
# Copyright 2001 Sun Microsystems, Inc.  All rights reserved.
#
# Description:
#	Modifies a schedule by first removing it and then re-adding it to the
# timer.  A bit heavy handed, perhaps, but does the trick.
#
use CCE;
use Data::Dumper;
use Schedule;

use vars qw($DEBUG);
$DEBUG = 0;

my $cce = new CCE;
$cce->connectfd();

# Get information on the object being modified.
my $oid = $cce->event_oid();
my $obj = $cce->event_object();
my $result = 0;

$DEBUG && print STDERR 'Schedule modify: working on object: ', Dumper($obj);

# Make sure we are not trying to modify the filename parameter
my $changed = $cce->event_new();
if (defined $changed{'filename'}) {
	# 
	# The user is not permitted to change the filename property.  Fail
	# with bad data.
	# 
	$DEBUG && print STDERR 'Schedule modify: changed fields: ', Dumper($changed);
	$cce->baddata($oid, 'filename', '[[base-schedule.filename_private]]');
	$cce->bye('FAIL');
	exit(1);
}

# Check the modified parameters for the new object
$ok = Schedule::check_parameters($cce, $obj);
if (! $ok) {
	#
	# Bad parameters is set by the check_parameters routine.  Just fail
	# here.
	#
	$DEBUG && print STDERR 'Schedule modify: check_parameters returned: ' .
	    $ok . "\n";
	$cce->bye('FAIL');
	exit(1);
}


# Remove any old schedule from the timer (cron).
$ok = Schedule::timer_delete($cce, $obj);
if (! $ok) {
	# Failed to remove the previous version of this schedule
	$DEBUG && print STDERR 'Schedule modify: timer_delete returned: ' .
	    $ok . "\n";
	$cce->bye('FAIL', '[[base-schedule.timer_delete_failed]]');
	exit(1);
}


# Determine if the schedule is active and if it should be added to the timer.
if ($obj->{'enabled'}) {
	$ok = Schedule::timer_add($cce, $obj);
	if (! $ok) {
		# Failed to remove the previous version of this schedule
		$cce->bye('FAIL', '[[base-schedule.timer_add_failed]]');
		exit(1);
	}
}

$cce->bye('SUCCESS');
exit(0);

